.. The reference section is for low-level documentation for programmers.
   There should be a file for each class
   Include Docstring and parameter expectations for each class

Reference
=========

.. toctree::
	:maxdepth: 2
	:glob:
   
	settings
	api
	template_tags